# Citations

The library has been cited in a variety of high-quality journals (list may be incomplete). Entries are roughly in reverse chronological order.

## Journal Articles, Conference Proceedings, and Preprints
1. Qian, Jimmy J., and Erol Akçay. [The balance of interaction types determines the assembly and stability of ecological communities](https://www.nature.com/articles/s41559-020-1121-x). Nature Ecology & Evolution (2020): 1-10. [BioRxiv](https://www.biorxiv.org/content/10.1101/643478v1.full) (2019): 643478.
1. Bucalo, Maria Soledad, et al. [A Constellation of Horrors: Analysis and Visualization of the #Cuéntalo Movement.](https://dl.acm.org/doi/abs/10.1145/3308560.3316459) Companion Proceedings of The 2019 World Wide Web Conference. 2019.
1. Broquet, Adrien Pierre Michel, Mark A. Wieczorek, and Wenzhe Fa. [Flexure of the lithosphere beneath the north polar cap of Mars, with implication for ice compositions and heat flow.](https://www.essoar.org/doi/abs/10.1002/essoar.10501496.1) (2019). [Preprint]
1. Ke, Huibin, and Christopher D. Taylor. [Design of Corrosion Resistant Alloys Using Density Functional Theory: Part I. O and Cl Adsorption Energy.](https://papers.ssrn.com/sol3/papers.cfm?abstract_id=3491237). O and Cl Adsorption Energy (November 27, 2019) (2019).
1. Choi, Kwangbom, Narayanan Raghupathy, and Gary A. Churchill. [scBASE: A Bayesian mixture model for the analysis of allelic expression in single cells.](https://www.nature.com/articles/s41467-019-13099-0) Nature Communications 10.1 (2019): 1-1. [bioRxiv](https://www.biorxiv.org/content/10.1101/383224v3.full) (2019): 383224.
1. Campbell, Ian Jackson, George Nelson Bennett, and Jonathan J. Silberg. [Evolutionary relationships between low potential ferredoxin and flavodoxin electron carriers.](https://www.frontiersin.org/articles/10.3389/fenrg.2019.00079/full) Frontiers in Energy Research 7 (2019): 79.
1. Bragman, Felix JS, et al. [Stochastic Filter Groups for Multi-Task CNNs: Learning Specialist and Generalist Convolution Kernels](http://openaccess.thecvf.com/content_ICCV_2019/html/Bragman_Stochastic_Filter_Groups_for_Multi-Task_CNNs_Learning_Specialist_and_Generalist_ICCV_2019_paper.html). Proceedings of the IEEE International Conference on Computer Vision. [arXiv:1908.09597](https://arxiv.org/abs/1908.09597) (2019).
1. Nelson, James, and Stefano Sanvito. Predicting the Curie temperature of ferromagnets using machine learning. [arXiv:1906.08534](https://arxiv.org/abs/1906.08534) (2019).
1. Kirchner, Philipp, et al. [Proteome-wide analysis of chaperone-mediated autophagy targeting motifs.](https://journals.plos.org/plosbiology/article?id=10.1371/journal.pbio.3000301) PLoS biology 17.5 (2019): e3000301.
1. Gariazzo, S., P. F. de Salas, and S. Pastor Carpi. [Thermalisation of sterile neutrinos in the early Universe in the 3+ 1 scheme with full mixing matrix](https://iopscience.iop.org/article/10.1088/1475-7516/2019/07/014).  Journal of Cosmology and Astroparticle Physics, Volume 2019, July 2019. [arXiv:1905.11290](https://arxiv.org/abs/1905.11290) (2019).
1. Keniley, Shane, and Davide Curreli. "CRANE: A MOOSE-based Open Source Tool for Plasma Chemistry Applications." [arXiv:1905.10004](https://arxiv.org/abs/1905.10004) (2019).
1. Abada, Asmaa, et al. [Inclusive displaced vertex searches for heavy neutral leptons at the LHC.](https://link.springer.com/article/10.1007/JHEP01(2019)093) Journal of High Energy Physics 2019.1 (2019): 93. [ArXiv](https://arxiv.org/abs/1807.10024).
1. Bustamante, Mauricio, and Sanjib Kumar Agarwalla. [Universe’s Worth of Electrons to Probe Long-Range Interactions of High-Energy Astrophysical Neutrinos.](https://journals.aps.org/prl/abstract/10.1103/PhysRevLett.122.061103) Physical review letters 122.6 (2019): 061103. [ArXiv](https://arxiv.org/abs/1808.02042).
1. Hamilton, Nicholas E., and Michael Ferry. [ggtern: Ternary diagrams using ggplot2](https://www.jstatsoft.org/article/view/v087c03). Journal of Statistical Software 87.1 (2018): 1-17.
1. [Insights into photovoltaic properties of ternary organic solar cells from phase diagrams](https://www.tandfonline.com/doi/abs/10.1080/14686996.2018.1509275). Makha, Mohammed, et al. Science and Technology of Advanced Materials 19.1 (2018): 669-682.
1. [Entropic Equilibria Selection of Stationary Extrema in Finite Populations](https://doi.org/10.3390/e20090631). Marc Harper
and Dashiell Fryer. Entropy 2018, 20(9), 631.
1. [Paleoenvironmental conditions and sedimentation dynamics in Central Europe inferred from geochemical data of the loess-paleosol sequence at Süttő (Hungary)](https://www.sciencedirect.com/science/article/pii/S027737911730834X). Profe, Jörn, et al. Quaternary Science Reviews 196 (2018): 21-37.
1. [Understanding the impacts of biomass blending on the uncertainty of hydrolyzed sugar yield from a stochastic perspective.](https://pubs.acs.org/doi/full/10.1021/acssuschemeng.8b02150#showReferences). Ou, Longwen, et al. ACS Sustainable Chemistry & Engineering (2018).
1. [NetworkGT: A GIS tool for geometric and topological analysis of two-dimensional fracture networks](https://pubs.geoscienceworld.org/gsa/geosphere/article/14/4/1618/531129/networkgt-a-gis-tool-for-geometric-and-topological). Nyberg, Björn, Casey W. Nixon, and David J. Sanderson. Geosphere (2018).
1. [Accelerated discovery of metallic glasses through iteration of machine learning and high-throughput experiments](http://advances.sciencemag.org/content/4/4/eaaq1566.full). Fang Ren, Logan Ward, Travis Williams, Kevin J. Laws, Christopher Wolverton, Jason Hattrick-Simpers and Apurva Mehta. Science Advances: Vol. 4, no. 4. (2018) DOI: 10.1126/sciadv.aaq1566
1. [Modeling CO, CO2, and H2O Ice Abundances in the Envelopes of Young Stellar Objects in the Magellanic Clouds](http://iopscience.iop.org/article/10.3847/1538-4357/aaa96a/meta). Pauly, Tyler, and Robin T. Garrod. The Astrophysical Journal, 854.1 (2018): 13.
1. [Enhanced CO2 selectivity within the cavity of gmelinite frameworks](https://link.springer.com/article/10.1007%2Fs10450-018-9945-2). Gotzias, A., Kainourgiakis, M. & Stubos, A. Adsorption (2018). https://doi.org/10.1007/s10450-018-9945-2
1. [Genetic Drift and Selection in Many-Allele Range Expansions](http://journals.plos.org/ploscompbiol/article?id=10.1371/journal.pcbi.1005866). [Bryan T. Weinstein](https://github.com/btweinstein), Maxim O. Lavrentovich, Wolfram Möbius, Andrew W. Murray, and David R. Nelson. PLoS computational biology 13.12 (2017): e1005866. (2017)
1. [Gibbs Sampler-Based λ-Dynamics and Rao–Blackwell Estimator for Alchemical Free Energy Calculation](http://pubs.acs.org/doi/abs/10.1021/acs.jctc.7b00204?src=recsys&journalCode=jctcce). Xinqiang Ding, Jonah Z. Vilseck, Ryan L. Hayes, and Charles L. Brooks. Journal of Chemical Theory and Computation. (2017)
1. [PREDICTD: PaRallel Epigenomics Data Imputation With Cloud-based Tensor Decomposition](http://biorxiv.org/content/early/2017/04/04/123927). Timothy J Durham, Maxwell W Libbrecht, Jeffry Howbert, Jeffrey Bilmes, William S Noble. Nature Communications, doi: 10.1038/s41467-018-03635-9 (2017)
1. Kottke, Daniel, et al. [Multi-class probabilistic active learning](http://ebooks.iospress.nl/publication/44803) Proc. of the 22nd Europ. Conf. on Artificial Intelligence (ECAI2016). 2016.
1. [On the origins of three-dimensionality in drug-like molecules](http://www.future-science.com/doi/full/10.4155/fmc-2016-0095). Joshua Meyers, Michael Carter, N Yi Mok, and Nathan Brown. Future Medicinal Chemistry, Vol. 8, No. 14 (2016)
1. [Stationary Stability for Evolutionary Dynamics in Finite Populations](http://www.mdpi.com/1099-4300/18/9/316/htm). Marc Harper and Dashiell Fryer. Entropy 18.9 (2016): 316.
1. [pyIAST: Ideal adsorbed solution theory (IAST) Python package](http://www.sciencedirect.com/science/article/pii/S0010465515004403). [Cory Simon](https://github.com/CorySimon). Computer Physics Communications (2016)
1. [Lyapunov Functions for Time-Scale Dynamics on Riemannian Geometries of the Simplex](https://link.springer.com/article/10.1007/s13235-014-0124-0). Marc Harper and Dashiell Fryer. Dynamic Games and Applications (2015)

## Dissertations
1. Cremer, Pascal. [Algorithms for Cell Layout](http://hss.ulb.uni-bonn.de/2019/5428/5428.pdf). PhD Dissertation. Universitäts-und Landesbibliothek Bonn, 2019.
1. Weinstein, Bryan T. [Microbial Evolutionary Dynamics and Transport on Solid and Liquid Substrates](https://dash.harvard.edu/handle/1/40050028). Diss. 2018.
1. Triller, Thomas. [Diffusive properties of the system water/ethanol/triethylene glycol in microgravity and ground conditions](https://d-nb.info/1168324432/34). (Disseration, 2018) 

# How to Cite

[Citation Instructions](CITATION.md)
